diff --git a/availability/condition/completion/tests/behat/availability_completion_previous.feature b/availability/condition/completion/tests/behat/availability_completion_previous.feature
index bf3848f319b..d80acaab947 100644
--- a/availability/condition/completion/tests/behat/availability_completion_previous.feature
+++ b/availability/condition/completion/tests/behat/availability_completion_previous.feature
@@ -32,7 +32,7 @@ Feature: Confirm that availability_completion works with previous activity setti
And I expand all fieldsets
And I click on "Add restriction..." "button"
And I click on "Activity completion" "button" in the "Add restriction..." "dialogue"
- And I click on "Displayed greyed-out if user does not meet this condition • Click to hide" "link"
+ And I click on "Displayed if student doesn't meet this condition • Click to hide" "link"
And I set the field "Activity or resource" to "Previous activity with completion"
And I press "Save and return to course"
Then I should see "Not available unless: The previous activity with completion" in the "region-main" "region"
@@ -58,7 +58,7 @@ Feature: Confirm that availability_completion works with previous activity setti
And I expand all fieldsets
And I click on "Add restriction..." "button"
And I click on "Activity completion" "button" in the "Add restriction..." "dialogue"
- And I click on "Displayed greyed-out if user does not meet this condition • Click to hide" "link"
+ And I click on "Displayed if student doesn't meet this condition • Click to hide" "link"
And I set the field "Activity or resource" to "Previous activity with completion"
And I press "Save and return to course"
Then I should see "Not available unless: The previous activity with completion" in the "region-main" "region"
@@ -83,7 +83,7 @@ Feature: Confirm that availability_completion works with previous activity setti
And I expand all fieldsets
And I click on "Add restriction..." "button"
And I click on "Activity completion" "button" in the "Add restriction..." "dialogue"
- And I click on "Displayed greyed-out if user does not meet this condition • Click to hide" "link"
+ And I click on "Displayed if student doesn't meet this condition • Click to hide" "link"
And I set the field "Activity or resource" to "Previous activity with completion"
And I press "Save and return to course"
Then I should see "Not available unless: The previous activity with completion" in the "region-main" "region"
@@ -112,7 +112,7 @@ Feature: Confirm that availability_completion works with previous activity setti
And I expand all fieldsets
And I click on "Add restriction..." "button"
And I click on "Activity completion" "button" in the "Add restriction..." "dialogue"
- And I click on "Displayed greyed-out if user does not meet this condition • Click to hide" "link"
+ And I click on "Displayed if student doesn't meet this condition • Click to hide" "link"
And I set the field "Activity or resource" to "Previous activity with completion"
And I press "Save changes"
Then I should see "Not available unless: The previous activity with completion" in the "region-main" "region"
@@ -138,7 +138,7 @@ Feature: Confirm that availability_completion works with previous activity setti
And I expand all fieldsets
And I click on "Add restriction..." "button"
And I click on "Activity completion" "button" in the "Add restriction..." "dialogue"
- And I click on "Displayed greyed-out if user does not meet this condition • Click to hide" "link"
+ And I click on "Displayed if student doesn't meet this condition • Click to hide" "link"
Then the "Activity or resource" select box should not contain "Previous activity with completion"
# Set Page2 restriction to Previous Activity with completion and delete Page1.
@@ -148,7 +148,7 @@ Feature: Confirm that availability_completion works with previous activity setti
And I expand all fieldsets
And I click on "Add restriction..." "button"
And I click on "Activity completion" "button" in the "Add restriction..." "dialogue"
- And I click on "Displayed greyed-out if user does not meet this condition • Click to hide" "link"
+ And I click on "Displayed if student doesn't meet this condition • Click to hide" "link"
And I set the field "Activity or resource" to "Previous activity with completion"
And I press "Save and return to course"
Then I should see "Not available unless: The previous activity with completion" in the "region-main" "region"
@@ -170,7 +170,7 @@ Feature: Confirm that availability_completion works with previous activity setti
And I expand all fieldsets
And I click on "Add restriction..." "button"
And I click on "Activity completion" "button" in the "Add restriction..." "dialogue"
- And I click on "Displayed greyed-out if user does not meet this condition • Click to hide" "link"
+ And I click on "Displayed if student doesn't meet this condition • Click to hide" "link"
And I set the field "Activity or resource" to "Previous activity with completion"
And I press "Save changes"
Then I should see "Not available unless: The previous activity with completion" in the "region-main" "region"
@@ -184,7 +184,7 @@ Feature: Confirm that availability_completion works with previous activity setti
And I expand all fieldsets
And I click on "Add restriction..." "button"
And I click on "Activity completion" "button" in the "Add restriction..." "dialogue"
- And I click on "Displayed greyed-out if user does not meet this condition • Click to hide" "link"
+ And I click on "Displayed if student doesn't meet this condition • Click to hide" "link"
And I set the field "Activity or resource" to "Previous activity with completion"
And I press "Save changes"
Then I should see "Not available unless: The previous activity with completion" in the "region-main" "region"
diff --git a/availability/condition/grade/lang/en/availability_grade.php b/availability/condition/grade/lang/en/availability_grade.php
index 74c786dd052..8d1c598e0a8 100644
--- a/availability/condition/grade/lang/en/availability_grade.php
+++ b/availability/condition/grade/lang/en/availability_grade.php
@@ -34,11 +34,11 @@ $string['option_min'] = 'must be ≥';
$string['option_max'] = 'must be <';
$string['pluginname'] = 'Restriction by grades';
$string['requires_any'] = 'You have a grade in {$a}';
-$string['requires_max'] = 'You get an appropriate score in {$a}';
-$string['requires_min'] = 'You achieve a required score in {$a}';
+$string['requires_max'] = 'You achieve lower than a certain score in {$a}';
+$string['requires_min'] = 'You achieve higher than a certain score in {$a}';
$string['requires_notany'] = 'You do not have a grade in {$a}';
$string['requires_notgeneral'] = 'You do not get certain scores in {$a}';
-$string['requires_range'] = 'You get a particular score in {$a}';
+$string['requires_range'] = 'You achieve a score within a certain range in {$a}';
$string['missing'] = '(missing activity)';
$string['title'] = 'Grade';
$string['privacy:metadata'] = 'The Restriction by grades plugin does not store any personal data.';
diff --git a/availability/condition/grade/tests/behat/availability_grade.feature b/availability/condition/grade/tests/behat/availability_grade.feature
index 74e5915633c..662f068cafc 100644
--- a/availability/condition/grade/tests/behat/availability_grade.feature
+++ b/availability/condition/grade/tests/behat/availability_grade.feature
@@ -159,5 +159,5 @@ Feature: availability_grade
# Student sees information about no access to group, with group name in correct language.
When I am on the "C1" "Course" page logged in as "student1"
- Then I should see "Not available unless: You achieve a required score in A-One"
+ Then I should see "Not available unless: You achieve higher than a certain score in A-One"
And I should not see "A-Un"
diff --git a/availability/condition/grade/tests/condition_test.php b/availability/condition/grade/tests/condition_test.php
index 0cf0cd27a2e..28c0b35b0e0 100644
--- a/availability/condition/grade/tests/condition_test.php
+++ b/availability/condition/grade/tests/condition_test.php
@@ -77,7 +77,7 @@ class condition_test extends \advanced_testcase {
$this->assertFalse($cond->is_available(false, $info, true, $user->id));
$information = $cond->get_description(false, false, $info);
$information = \core_availability\info::format_info($information, $course);
- $this->assertMatchesRegularExpression('~achieve a required score.*Test!~', $information);
+ $this->assertMatchesRegularExpression('~achieve higher than.*Test!~', $information);
$this->assertTrue($cond->is_available(true, $info, true, $user->id));
// Min grade (success).
@@ -95,7 +95,7 @@ class condition_test extends \advanced_testcase {
$this->assertFalse($cond->is_available(false, $info, true, $user->id));
$information = $cond->get_description(false, false, $info);
$information = \core_availability\info::format_info($information, $course);
- $this->assertMatchesRegularExpression('~get an appropriate score.*Test!~', $information);
+ $this->assertMatchesRegularExpression('~achieve lower than a certain score in.*Test!~', $information);
$this->assertTrue($cond->is_available(true, $info, true, $user->id));
// Max grade (success).
@@ -113,7 +113,7 @@ class condition_test extends \advanced_testcase {
$this->assertFalse($cond->is_available(false, $info, true, $user->id));
$information = $cond->get_description(false, false, $info);
$information = \core_availability\info::format_info($information, $course);
- $this->assertMatchesRegularExpression('~get a particular score.*Test!~', $information);
+ $this->assertMatchesRegularExpression('~achieve a score within a certain range.*Test!~', $information);
$this->assertTrue($cond->is_available(true, $info, true, $user->id));
// Still fail (other end).
diff --git a/availability/tests/behat/edit_availability.feature b/availability/tests/behat/edit_availability.feature
index 7ae4b195bcb..d88bd12c33a 100644
--- a/availability/tests/behat/edit_availability.feature
+++ b/availability/tests/behat/edit_availability.feature
@@ -86,13 +86,13 @@ Feature: edit_availability
And I should see "Date" in the "Restrict access" "fieldset"
And ".availability-item .availability-eye img" "css_element" should be visible
And ".availability-item .availability-delete img" "css_element" should be visible
- And the "alt" attribute of ".availability-item .availability-eye img" "css_element" should contain "Displayed greyed-out"
+ And the "alt" attribute of ".availability-item .availability-eye img" "css_element" should contain "Displayed if student"
# Toggle the eye icon.
When I click on ".availability-item .availability-eye img" "css_element"
Then the "alt" attribute of ".availability-item .availability-eye img" "css_element" should contain "Hidden entirely"
When I click on ".availability-item .availability-eye img" "css_element"
- Then the "alt" attribute of ".availability-item .availability-eye img" "css_element" should contain "Displayed greyed-out"
+ Then the "alt" attribute of ".availability-item .availability-eye img" "css_element" should contain "Displayed if student"
# Click the delete button.
When I click on ".availability-item .availability-delete img" "css_element"
diff --git a/completion/tests/behat/activity_completion_criteria.feature b/completion/tests/behat/activity_completion_criteria.feature
index 2f4a31e9d6c..7c6079370a8 100644
--- a/completion/tests/behat/activity_completion_criteria.feature
+++ b/completion/tests/behat/activity_completion_criteria.feature
@@ -135,7 +135,7 @@ Feature: Allow to mark course as completed without cron for activity completion
And I am on "Completion course" course homepage
And I navigate to "View > Grader report" in the course gradebook
And I follow "Single view"
- And I select "Student First" from the "View all the grades of a single user" singleselect
+ And I select "Student First" from the "Select a user above to view all their grades" singleselect
And I set the field "Override for Test assignment name" to "1"
When I set the following fields to these values:
| Grade for Test assignment name | 10.00 |
diff --git a/completion/tests/behat/restrict_activity_by_grade.feature b/completion/tests/behat/restrict_activity_by_grade.feature
index 196bbfa814b..ff1aad546fb 100644
--- a/completion/tests/behat/restrict_activity_by_grade.feature
+++ b/completion/tests/behat/restrict_activity_by_grade.feature
@@ -43,7 +43,7 @@ Feature: Restrict activity availability through grade conditions
And I log out
When I am on the "Course 1" course page logged in as student1
- Then I should see "Not available unless: You achieve a required score in Grade assignment"
+ Then I should see "Not available unless: You achieve higher than a certain score in Grade assignment"
And I should see "Test page name"
And "Test page name" "link" should not exist in the "region-main" "region"
And I am on the "Grade assignment" "assign activity" page
@@ -65,4 +65,4 @@ Feature: Restrict activity availability through grade conditions
And I am on the "Course 1" course page logged in as student1
And "Test page name" activity should be visible
- And I should not see "Not available unless: You achieve a required score in Grade assignment"
+ And I should not see "Not available unless: You achieve higher than a certain score in Grade assignment"
diff --git a/completion/tests/behat/restrict_section_availability.feature b/completion/tests/behat/restrict_section_availability.feature
index 308beac0fce..216c3411cde 100644
--- a/completion/tests/behat/restrict_section_availability.feature
+++ b/completion/tests/behat/restrict_section_availability.feature
@@ -78,7 +78,7 @@ Feature: Restrict sections availability through completion or grade conditions
And I log out
When I log in as "student1"
And I am on "Course 1" course homepage
- Then I should see "Not available unless: You achieve a required score in Grade assignment"
+ Then I should see "Not available unless: You achieve higher than a certain score in Grade assignment"
And "Test page name" activity should be hidden
And I am on the "Grade assignment" "assign activity" page
And I press "Add submission"
@@ -97,4 +97,4 @@ Feature: Restrict sections availability through completion or grade conditions
And I log out
And I am on the "Course 1" Course page logged in as student1
And "Test page name" activity should be visible
- And I should not see "Not available unless: You achieve a required score in Grade assignment"
+ And I should not see "Not available unless: You achieve higher than a certain score in Grade assignment"
diff --git a/grade/report/singleview/lang/en/gradereport_singleview.php b/grade/report/singleview/lang/en/gradereport_singleview.php
index fbf570ba492..683d3e40f3d 100644
--- a/grade/report/singleview/lang/en/gradereport_singleview.php
+++ b/grade/report/singleview/lang/en/gradereport_singleview.php
@@ -27,8 +27,8 @@ $string['all_grades'] = 'All grades';
$string['assessmentname'] = 'Grade item';
$string['blanks'] = 'Empty grades';
$string['bulkappliesto'] = 'For';
-$string['bulkinsertvalue'] = 'Insert value';
-$string['bulklegend'] = 'Bulk insert';
+$string['bulkinsertvalue'] = 'Insert new grade';
+$string['bulklegend'] = 'Bulk insert grades';
$string['bulkperform'] = 'Perform bulk insert';
$string['bulkfor'] = 'Grades for {$a}';
$string['entrypage'] = 'Grade user or grade item';
@@ -56,8 +56,8 @@ $string['privacy:metadata'] = 'The Grade single view report only shows data stor
$string['savegrades'] = 'Saving grades';
$string['save'] = 'Save';
$string['savegradessuccess'] = 'Grades were set for {$a} items';
-$string['selectgrade'] = 'View a single grade item';
-$string['selectuser'] = 'View all the grades of a single user';
+$string['selectgrade'] = 'Select a grade item above';
+$string['selectuser'] = 'Select a user above to view all their grades';
$string['singleview:view'] = 'View single view';
$string['summarygrade'] = 'A table of users, with columns for range, grade, feedback, and whether to override or exclude a particular grade.';
$string['summaryuser'] = 'A table of grade items, with columns for grade category, range, grade, feedback, and whether to override or exclude a particular grade.';
diff --git a/grade/report/singleview/tests/behat/bulk_insert_grades.feature b/grade/report/singleview/tests/behat/bulk_insert_grades.feature
index bf135cf64c6..3b87b92c457 100644
--- a/grade/report/singleview/tests/behat/bulk_insert_grades.feature
+++ b/grade/report/singleview/tests/behat/bulk_insert_grades.feature
@@ -42,7 +42,7 @@ Feature: We can bulk insert grades for students in a course
Then the field "Grade for Student 1" matches value "50.00"
And the field "Override for Student 1" matches value "0"
And I set the field "Perform bulk insert" to "1"
- And I set the field "Insert value" to "1.0"
+ And I set the field "Insert new grade" to "1.0"
And I press "Save"
And the field "Grade for Student 1" matches value "50.00"
And the field "Override for Student 1" matches value "0"
@@ -54,7 +54,7 @@ Feature: We can bulk insert grades for students in a course
And the field "Override for Student 4" matches value "1"
And I set the field "For" to "All grades"
And I set the field "Perform bulk insert" to "1"
- And I set the field "Insert value" to "2.0"
+ And I set the field "Insert new grade" to "2.0"
And I press "Save"
And the field "Grade for Student 1" matches value "2.00"
And the field "Override for Student 1" matches value "1"
@@ -77,12 +77,12 @@ Feature: We can bulk insert grades for students in a course
# And I click on "input[title='Dock Navigation block']" "css_element"
# And I click on "input[title='Dock Administration block']" "css_element"
And I follow "Single view for Test assignment two"
- And I select "Student 1" from the "View all the grades of a single user" singleselect
+ And I select "Student 1" from the "Select a user above to view all their grades" singleselect
Then the field "Grade for Test assignment two" matches value "50.00"
And the field "Override for Test assignment two" matches value "0"
And I set the field "For" to "Empty grades"
And I set the field "Perform bulk insert" to "1"
- And I set the field "Insert value" to "1.0"
+ And I set the field "Insert new grade" to "1.0"
And I press "Save"
And the field "Grade for Test assignment two" matches value "50.00"
And the field "Override for Test assignment two" matches value "0"
@@ -98,7 +98,7 @@ Feature: We can bulk insert grades for students in a course
And I navigate to "View > Grader report" in the course gradebook
And I follow "Single view for Test assignment one"
And I set the field "Perform bulk insert" to "1"
- When I set the field "Insert value" to "-1"
+ When I set the field "Insert new grade" to "-1"
And I press "Save"
Then I should see "The grade entered for Test assignment one for Student 1 is less than the minimum allowed"
And I should see "The grade entered for Test assignment one for Student 2 is less than the minimum allowed"
diff --git a/grade/report/singleview/tests/behat/singleview.feature b/grade/report/singleview/tests/behat/singleview.feature
index c3ceb4d29be..a6fe348d759 100644
--- a/grade/report/singleview/tests/behat/singleview.feature
+++ b/grade/report/singleview/tests/behat/singleview.feature
@@ -60,7 +60,7 @@ Feature: We can use Single view
@javascript
Scenario: I can update grades, add feedback and exclude grades.
Given I navigate to "View > Single view" in the course gradebook
- And I select "Student" from the "View all the grades of a single user" singleselect
+ And I select "Student" from the "Select a user above to view all their grades" singleselect
And I set the field "Override for Test assignment one" to "1"
When I set the following fields to these values:
| Grade for Test assignment one | 10.00 |
@@ -86,7 +86,7 @@ Feature: We can use Single view
Then I should see "Grades were set for 2 items"
And the field "Grade for Ann, Jill, Grainne, Beauchamp" matches value "12.05"
And the field "Exclude for Jane, Nina, Niamh, Cholmondely" matches value "1"
- And I select "new grade item 1" from the "View a single grade item" singleselect
+ And I select "new grade item 1" from the "Select a grade item above" singleselect
And I set the field "Grade for Ann, Jill, Grainne, Beauchamp" to "Very good"
And I press "Save"
Then I should see "Grades were set for 1 items"
@@ -97,7 +97,7 @@ Feature: We can use Single view
And I log in as "teacher2"
And I am on "Course 1" course homepage
Given I navigate to "View > Single view" in the course gradebook
- And I select "Student" from the "View all the grades of a single user" singleselect
+ And I select "Student" from the "Select a user above to view all their grades" singleselect
And the "Exclude for Test assignment one" "checkbox" should be disabled
And the "Override for Test assignment one" "checkbox" should be enabled
@@ -112,7 +112,7 @@ Feature: We can use Single view
Given I follow "Single view for Ann, Jill, Grainne, Beauchamp"
Then I should see "Gronya,Beecham"
When I set the field "For" to "All grades"
- And I set the field "Insert value" to "1.0"
+ And I set the field "Insert new grade" to "1.0"
And I set the field "Perform bulk insert" to "1"
And I press "Save"
Then I should see "Grades were set for 6 items"
@@ -124,7 +124,7 @@ Feature: We can use Single view
And I follow "Single view for Ann, Jill, Grainne, Beauchamp"
And I should see "Gronya,Beecham"
When I set the field "For" to "All grades"
- And I set the field "Insert value" to "1#25"
+ And I set the field "Insert new grade" to "1#25"
And I set the field "Perform bulk insert" to "1"
And I press "Save"
Then I should see "Grades were set for 6 items"
diff --git a/lang/en/availability.php b/lang/en/availability.php
index 71458ed1d93..75bdadf825e 100644
--- a/lang/en/availability.php
+++ b/lang/en/availability.php
@@ -31,15 +31,15 @@ $string['enableavailability'] = 'Enable restricted access';
$string['enableavailability_desc'] = 'If enabled, conditions (based on date, grade, completion etc.) may be set to control whether an activity or resource can be accessed.';
$string['error_list_nochildren'] = 'Restriction sets should contain at least one condition.';
$string['hidden_marker'] = '(hidden otherwise)';
-$string['hidden_individual'] = 'Hidden entirely if user does not meet this condition';
+$string['hidden_individual'] = 'Hidden entirely if student doesn\'t meet this condition';
$string['invalid'] = 'Please set';
$string['itemheading'] = '{$a->number} {$a->type} restriction';
$string['item_unknowntype'] = 'These restrictions use a plugin which is no longer available (if it is okay to remove that restriction, delete it below)';
-$string['shown_individual'] = 'Displayed greyed-out if user does not meet this condition';
+$string['shown_individual'] = 'Displayed if student doesn\'t meet this condition';
$string['hide_verb'] = 'Click to hide';
-$string['show_verb'] = 'Click to display greyed-out';
-$string['hidden_all'] = 'Hidden entirely if user does not meet conditions';
-$string['shown_all'] = 'Displayed greyed-out if user does not meet conditions';
+$string['show_verb'] = 'Click to display';
+$string['hidden_all'] = 'Hidden entirely if student doesn\'t meet the conditions';
+$string['shown_all'] = 'Displayed if student doesn\'t meet the conditions';
$string['label_multi'] = 'Required restrictions';
$string['label_sign'] = 'Restriction type';
$string['list_and'] = 'All of:';
diff --git a/lang/en/mnet.php b/lang/en/mnet.php
index 2641107fe85..b69c0a22e4b 100644
--- a/lang/en/mnet.php
+++ b/lang/en/mnet.php
@@ -82,7 +82,7 @@ $string['hideremote'] = 'Hide remote users';
$string['host'] = 'host';
$string['hostcoursenotfound'] = 'Host or course not found';
$string['hostdeleted'] = 'Host deleted';
-$string['hostexists'] = 'A record already exists for a host with that hostname (it may be deleted). Click here to edit that record.';
+$string['hostexists'] = 'A record already exists for a host with that hostname. (It may have been deleted.) Edit the record';
$string['hostlist'] = 'List of networked hosts';
$string['hostname'] = 'Hostname';
$string['hostnamehelp'] = 'The fully-qualified domain name of the remote host, e.g. www.example.com';
diff --git a/lib/editor/tinymce/lang/en/editor_tinymce.php b/lib/editor/tinymce/lang/en/editor_tinymce.php
index 3298ea41c65..1ee284d6931 100644
--- a/lib/editor/tinymce/lang/en/editor_tinymce.php
+++ b/lib/editor/tinymce/lang/en/editor_tinymce.php
@@ -305,19 +305,19 @@ $string['colors:00CCFF'] = 'Sky blue';
$string['colors:00FF00'] = 'Lime';
$string['colors:00FFFF'] = 'Aqua';
$string['colors:333300'] = 'Dark olive';
-$string['colors:333333'] = 'Very dark gray';
+$string['colors:333333'] = 'Very dark grey';
$string['colors:333399'] = 'Indigo';
$string['colors:3366FF'] = 'Royal blue';
$string['colors:339966'] = 'Sea green';
$string['colors:33CCCC'] = 'Turquoise';
-$string['colors:666699'] = 'Grayish blue';
+$string['colors:666699'] = 'Greyish blue';
$string['colors:800000'] = 'Maroon';
$string['colors:800080'] = 'Purple';
$string['colors:808000'] = 'Olive';
-$string['colors:808080'] = 'Gray';
+$string['colors:808080'] = 'Grey';
$string['colors:993300'] = 'Burnt orange';
$string['colors:993366'] = 'Brown';
-$string['colors:999999'] = 'Medium gray';
+$string['colors:999999'] = 'Medium grey';
$string['colors:99CC00'] = 'Yellow green';
$string['colors:99CCFF'] = 'Light sky blue';
$string['colors:C0C0C0'] = 'Silver';
diff --git a/mod/data/lang/en/data.php b/mod/data/lang/en/data.php
index cd81b3c86ee..2d29232ca2c 100644
--- a/mod/data/lang/en/data.php
+++ b/mod/data/lang/en/data.php
@@ -59,7 +59,7 @@ $string['calendarstart'] = '{$a} opens';
$string['cancel'] = 'Cancel';
$string['cannotaccesspresentsother'] = 'You are not allowed to access presets from other users';
$string['cannotadd'] = 'Can not add entries!';
-$string['cannotdeletepreset'] = 'Error deleting a preset!';
+$string['cannotdeletepreset'] = 'Error deleting preset';
$string['cannotoverwritepreset'] = 'Error overwriting preset';
$string['cannotunziptopreset'] = 'Cannot unzip to the preset directory';
$string['closebeforeopen'] = 'You have specified an end date before the start date.';
@@ -142,7 +142,7 @@ $string['eventtemplateupdated'] = 'Template updated';
$string['eventtemplateviewed'] = 'Templates viewed';
$string['fileencoding'] = 'Encoding';
$string['entries'] = 'Entries';
-$string['entrieslefttoadd'] = 'You must add {$a->entriesleft} more entry/entries in order to complete this activity';
+$string['entrieslefttoadd'] = 'You must add {$a->entriesleft} more entry/entries to complete this activity.';
$string['entrieslefttoaddtoview'] = 'You must add {$a->entrieslefttoview} more entry/entries before you can view other participants\' entries.';
$string['entry'] = 'Entry';
$string['entrysaved'] = 'Your entry has been saved';
@@ -252,7 +252,7 @@ $string['listtemplate'] = 'List view template';
$string['longitude'] = 'Longitude';
$string['manageapproved'] = 'Allow editing of approved entries';
$string['managefields'] = 'Manage fields';
-$string['manageapproved_help'] = 'If disabled, approved entries are no longer editable or deletable by the user who added them. This setting has no effect unless \'Approval required\' is enabled.';
+$string['manageapproved_help'] = 'Allow students to edit or delete their entries after they’ve been approved. Edited entries will need to be reapproved.';
$string['mapexistingfield'] = 'Map to {$a}';
$string['mapnewfield'] = 'Create a new field';
$string['mappingwarning'] = 'All old fields not mapped to a new field will be lost and all data in that field will be removed.';
@@ -261,7 +261,7 @@ $string['maxentries_help'] = 'The maximum number of entries a student is allowed
$string['maxsize'] = 'Maximum size';
$string['menu'] = 'Menu';
$string['menuchoose'] = 'Choose...';
-$string['missingdata'] = 'Data id or object must be provided to field class';
+$string['missingdata'] = 'Data ID or object must be provided for field class.';
$string['missingfield'] = 'Programmer error: You must specify field and/or data when defining field class.';
$string['modulename'] = 'Database';
$string['modulename_help'] = 'Database enables participants to create, maintain, and search a collection of entries.
@@ -325,14 +325,14 @@ $string['presetinfo'] = 'Saving as a preset will publish this template. Other us
$string['presetnotselected'] = 'No preset has been selected.';
$string['presets'] = 'Presets';
$string['privacy:metadata:commentpurpose'] = 'Comments on database records';
-$string['privacy:metadata:data_content'] = 'Represents one answer to one field in database activity module';
+$string['privacy:metadata:data_content'] = 'The content of a field';
$string['privacy:metadata:data_content:fieldid'] = 'Field definition ID';
$string['privacy:metadata:data_content:content'] = 'Content';
$string['privacy:metadata:data_content:content1'] = 'Additional content 1';
$string['privacy:metadata:data_content:content2'] = 'Additional content 2';
$string['privacy:metadata:data_content:content3'] = 'Additional content 3';
$string['privacy:metadata:data_content:content4'] = 'Additional content 4';
-$string['privacy:metadata:data_records'] = 'Represent records in database acitivity module';
+$string['privacy:metadata:data_records'] = 'Records in the database activity';
$string['privacy:metadata:data_records:userid'] = 'User who created the record';
$string['privacy:metadata:data_records:groupid'] = 'Group';
$string['privacy:metadata:data_records:timecreated'] = 'Time when record was created';
@@ -350,7 +350,7 @@ $string['recordsnotsaved'] = 'No entry was saved. Please check the format of the
$string['recordssaved'] = 'entries saved';
$string['removealldatatags'] = 'Remove all database tags';
$string['requireapproval'] = 'Approval required';
-$string['requireapproval_help'] = 'If enabled, entries require approving by a teacher before they are viewable by everyone.';
+$string['requireapproval_help'] = 'A teacher has to approve entries before they’re visible to everyone.';
$string['required'] = 'Required';
$string['requiredentries'] = 'Entries required for completion (old)';
$string['requiredentries_help'] = "If set, a message is displayed stating the number of entries required for completion. Note that this setting is not connected to activity completion.
@@ -359,9 +359,9 @@ For entries required for activity completion, the new Activity completion settin
Please use the Entries required fields in the Activity completion section instead.";
$string['requiredentrieswarning'] = 'This setting has been replaced by an Activity completion setting "Require entries"';
$string['requiredentriestoview'] = 'Entries required before viewing';
-$string['requiredentriestoview_help'] = 'The number of entries a student is required to submit before they can view entries from other students.
+$string['requiredentriestoview_help'] = 'The number of entries a student is required to add before they can view entries from other students.
-Note: If entries are required before viewing, the database auto-linking filter should be disabled. This is because the database auto-linking filter can\'t determine whether a user has submitted the required number of entries.';
+This is not compatible with the database auto-linking filter.';
$string['requiredfield'] = 'Required field';
$string['resetsettings'] = 'Reset filters';
$string['resettemplate'] = 'Reset template';
@@ -376,7 +376,7 @@ $string['saveandadd'] = 'Save and add another';
$string['saveandview'] = 'Save and view';
$string['saveaspreset'] = 'Save as preset';
$string['saveaspreset_help'] = 'The save as preset feature publishes the templates and fields as a preset which others on the site can then use. (You may delete it from the list of presets at any time.)';
-$string['savedataaspreset'] = 'Save all fields and templates as preset';
+$string['savedataaspreset'] = 'Save all fields and templates and publish as preset on this site';
$string['saveaspresetmissingcapability'] = 'The user does not have permission to save the database as a preset.';
$string['savesettings'] = 'Save settings';
$string['savesuccess'] = 'Saved successfully. Your preset will now be available across the site.';
@@ -432,7 +432,7 @@ $string['viewfromdate'] = 'Read only from';
$string['viewnavigation'] = 'View mode tertiary navigation';
$string['viewtodate'] = 'Read only to';
$string['viewtodatevalidation'] = 'The read only to date cannot be before the read only from date.';
-$string['wrongdataid'] = 'Wrong data id provided';
+$string['wrongdataid'] = 'Wrong data ID provided';
// Deprecated since Moodle 3.11.
$string['unsupportedexport'] = '({$a->fieldtype}) cannot be exported.';
diff --git a/mod/forum/lang/en/forum.php b/mod/forum/lang/en/forum.php
index f466ab43479..b16aebc9d6d 100644
--- a/mod/forum/lang/en/forum.php
+++ b/mod/forum/lang/en/forum.php
@@ -95,7 +95,7 @@ $string['cannotfavourite'] = 'Sorry, but you do not have the permission to star
$string['cannottrack'] = 'Could not stop tracking that forum';
$string['cannotunsubscribe'] = 'Could not unsubscribe you from that forum';
$string['cannotupdatepost'] = 'You can not update this post';
-$string['cannotviewpostyet'] = 'You cannot read other students questions in this discussion yet because you haven\'t posted';
+$string['cannotviewpostyet'] = 'You can\'t read other students\' posts in this discussion yet because you haven\'t posted.';
$string['cannotviewusersposts'] = 'There are no posts made by this user that you are able to view.';
$string['cleanreadtime'] = 'Mark old posts as read hour';
$string['clicktolockdiscussion'] = 'Click to lock this discussion';
@@ -337,7 +337,7 @@ $string['forumtype_help'] = 'There are 5 forum types:
* A single simple discussion - A single discussion topic which everyone can reply to (cannot be used with separate groups)
* Each person posts one discussion - Each student can post exactly one new discussion topic, which everyone can then reply to
* Q and A forum - Students must first post their perspectives before viewing other students\' posts
* Standard forum displayed in a blog-like format - An open forum where anyone can start a new discussion at any time, and in which discussion topics are displayed on one page with "Discuss this topic" links
* Standard forum for general use - An open forum where anyone can start a new discussion at any time';
$string['forum:viewallratings'] = 'View all raw ratings given by individuals';
@@ -608,7 +608,7 @@ $string['prunediscussion'] = 'Split discussion';
$string['prunedpost'] = 'A new discussion has been created from that post';
$string['pruneheading'] = 'Split the discussion and move this post to a new discussion';
$string['qandaforum'] = 'Q and A forum';
-$string['qandanotify'] = 'This is a question and answer forum. In order to see other responses to these questions, you must first post your answer';
+$string['qandanotify'] = 'This is a question and answer forum. To see other replies, you must first post your reply.';
$string['re'] = 'Re:';
$string['readtherest'] = 'Read the rest of this topic';
$string['removeallforumtags'] = 'Remove all forum tags';
@@ -337,7 +337,7 @@ $string['forumtype_help'] = 'There are 5 forum types:
* A single simple discussion - A single discussion topic which everyone can reply to (cannot be used with separate groups)
* Each person posts one discussion - Each student can post exactly one new discussion topic, which everyone can then reply to
-* Q and A forum - Students must first post their perspectives before viewing other students\' posts
+* Q and A forum - A student must first post their reply to a question posted by the teacher, before viewing other students\' posts
* Standard forum displayed in a blog-like format - An open forum where anyone can start a new discussion at any time, and in which discussion topics are displayed on one page with "Discuss this topic" links
* Standard forum for general use - An open forum where anyone can start a new discussion at any time';